
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.19.3',
    'branch_nick': 'patch-0-Rucio_1_19_3_preparation',
    'revision_id': 'f4cb90164279a27379209455e808372796df6b46',
    'revno': 7826
}
